==> haskell-hasql-implicits-0.1.0.5-306.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-F43A5NZxKrpIJ9zVJhuqDQ
key:                  hasql-implicits-0.1.0.5-F43A5NZxKrpIJ9zVJhuqDQ
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  7f5a20c4943814a591250b576b70f331
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-F43A5NZxKrpIJ9zVJhuqDQ
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-D13dwG1Hnoj5UOBosN4Mcc
    network-ip-0.3.0.3-CPrEVCVHqj3xsde91Vvpj
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2 time-1.12.2
    uuid-1.3.16-GebAPnJBeXo3Et5zvwjxGZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-implicits-0.1.0.5-307-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-implicits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-implicits
version:              0.1.0.5
visibility:           public
id:                   hasql-implicits-0.1.0.5-AmBtfOzperTDwrZn3KQZ75
key:                  hasql-implicits-0.1.0.5-AmBtfOzperTDwrZn3KQZ75
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-implicits
synopsis:
    Implicit definitions for Hasql, such as default codecs for standard types

abi:                  3cdc29de011dfeae2b6be1408e8c9a8c
exposed:              True
exposed-modules:      Hasql.Implicits.Encoders
hidden-modules:       Hasql.Implicits.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-implicits-0.1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-implicits
hs-libraries:         HShasql-implicits-0.1.0.5-AmBtfOzperTDwrZn3KQZ75
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hasql-1.5.0.5-D56QxJSATLi7EO6Br9LDFG
    network-ip-0.3.0.3-F4S0hl1urBII3K2hMgQak8
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2 time-1.12.2
    uuid-1.3.16-8QEdndSNqxbGO60kyYYcsS
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-hasql-implicits/html/hasql-implicits.haddock

haddock-html:         /usr/share/doc/haskell-hasql-implicits/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
